#r "System.Windows.Forms"
#r "Microsoft.VisualBasic"

using System.Windows.Forms;
using Microsoft.VisualBasic;

var doc = Application.ActiveDocument;

// 選択されている図形を取得する
var selectedShapes = doc.SelectionManager.SelectedShapes;

// 選択数をチェック
if(selectedShapes.Count != 1)
{
    MessageBox.Show("１つの図形を選択してください。");
    return;
}

// スタイル
ShapeSettingsStyleCollection shapeSettingsStyles;

// 図形タイプごとのスタイルコレクションを取得
Shape shape = selectedShapes[0].Shape;

if(shape is BasicShape)             // 一般図形
    shapeSettingsStyles = doc.BasicShapeSettingsStyles;
else if(shape is PointMarkerShape)  // 点
    shapeSettingsStyles = doc.PointMarkerSettingsStyles;
else if(shape is TextShape)         // 文字
    shapeSettingsStyles = doc.TextSettingsStyles;
else if(shape is LeadShape)         // 引き出し線
    shapeSettingsStyles = doc.LeadSettingsStyles;
else if(shape is BalloonShape)      // バルーン
    shapeSettingsStyles = doc.BalloonSettingsStyles;
else if(shape is DimensionShape)    // 寸法
    shapeSettingsStyles = doc.DimensionSettingsStyles;
else if(shape is HatchShape)        // ハッチング
    shapeSettingsStyles = doc.HatchSettingsStyles;
else
{
    MessageBox.Show("この図形はスタイル登録できません。");
    return;
}

// 重複しないスタイル名を決定する
int n = 2;
string styleName = "新しいスタイル";
while(true)
{
    if(shapeSettingsStyles[styleName] != null)
    {
        while(shapeSettingsStyles.Any(shapeSettingsStyle => shapeSettingsStyle.Name == n.ToString(styleName + " (0)")))
            n++;
        styleName = n.ToString(styleName + " (0)");
    }

    // 入力ダイアログ表示   
    styleName = Interaction.InputBox("スタイル名を入力してください。", "スタイルの登録", styleName);

    if(string.IsNullOrEmpty(styleName))
        return;

    if(shapeSettingsStyles[styleName] != null)
        MessageBox.Show("スタイル名 [" +  styleName + "] はすでに登録されています。");
    else
        break;
}

// スタイル新規登録
ShapeSettingsStyle style = shapeSettingsStyles.Add(styleName);

// 図形タイプごとに設定
if(shape is BasicShape)             // 一般図形
{
    var settings = (BasicShapeSettings)style.Settings;
    settings.Color = ((BasicShape)shape).Color;
    settings.Linetype = ((BasicShape)shape).Linetype;
    settings.Linewidth = ((BasicShape)shape).Linewidth;
}
else if(shape is PointMarkerShape)  // 点
{
    var settings = (PointMarkerSettings)style.Settings;
    settings.MarkerType = ((PointMarkerShape)shape).MarkerType;
    settings.Size = ((PointMarkerShape)shape).Size;
    settings.Angle = ((PointMarkerShape)shape).Angle;
    settings.Color = ((PointMarkerShape)shape).Color;
}
else if(shape is TextShape)         // 文字
{
    var settings = (TextSettings)style.Settings;
    settings.Alignment = ((TextShape)shape).Alignment;
    settings.Bold = ((TextShape)shape).Bold;
    settings.Color = ((TextShape)shape).Color;
    settings.DirectionVertical = ((TextShape)shape).DirectionVertical;
    settings.FontHeight = ((TextShape)shape).FontHeight;
    settings.FontName = ((TextShape)shape).FontName;
    settings.HorizontalReverse = ((TextShape)shape).HorizontalReverse;
    settings.LineSpacing = ((TextShape)shape).LineSpacing;
    settings.Outline = ((TextShape)shape).Outline;
    settings.Overline = ((TextShape)shape).Overline;
    settings.Slant = ((TextShape)shape).Slant;
    settings.Spacing = ((TextShape)shape).Spacing;
    settings.Strikeout = ((TextShape)shape).Strikeout;
    settings.Underline = ((TextShape)shape).Underline;
    settings.VerticalReverse = ((TextShape)shape).VerticalReverse;
    settings.WidthScale = ((TextShape)shape).WidthScale;
}
else if(shape is LeadShape)         // 引き出し線
{
    var settings = (LeadSettings)style.Settings;
    settings.ArrowSize = ((LeadShape)shape).ArrowSize;
    settings.ArrowType = ((LeadShape)shape).ArrowType;
    settings.Bold = ((LeadShape)shape).Bold;
    settings.Color = ((LeadShape)shape).Color;
    settings.FontHeight = ((LeadShape)shape).FontHeight;
    settings.FontName = ((LeadShape)shape).FontName;
    settings.Linetype = ((LeadShape)shape).Linetype;
    settings.Linewidth = ((LeadShape)shape).Linewidth;
    settings.Slant = ((LeadShape)shape).Slant;
    settings.Spacing = ((LeadShape)shape).Spacing;
    settings.TextAngleType = ((LeadShape)shape).TextAngleType;
    settings.TextAngle = ((LeadShape)shape).TextAngle;
    settings.TextColor = ((LeadShape)shape).TextColor;
    settings.TextLastpointDistance = ((LeadShape)shape).TextLastpointDistance;
    settings.TextUnderline = ((LeadShape)shape).TextUnderline;
    settings.TextUnderlineExtension = ((LeadShape)shape).TextUnderlineExtension;
    settings.TextVerticalDistance = ((LeadShape)shape).TextVerticalDistance;
    settings.TextVerticalPosition = ((LeadShape)shape).TextVerticalPosition;
    settings.UseTextColor = ((LeadShape)shape).UseTextColor;
    settings.WidthScale = ((LeadShape)shape).WidthScale;
}
else if(shape is BalloonShape)      // バルーン
{
    var settings = (BalloonSettings)style.Settings;
    settings.ArrowSize = ((BalloonShape)shape).ArrowSize;
    settings.ArrowType = ((BalloonShape)shape).ArrowType;
    settings.BalloonType = ((BalloonShape)shape).BalloonType;
    settings.Bold = ((BalloonShape)shape).Bold;
    settings.Color = ((BalloonShape)shape).Color;
    settings.FontName = ((BalloonShape)shape).FontName;
    settings.LeadColor = ((BalloonShape)shape).LeadColor;
    settings.LeadLinetype = ((BalloonShape)shape).LeadLinetype;
    settings.LeadLinewidth = ((BalloonShape)shape).LeadLinewidth;
    settings.Linetype = ((BalloonShape)shape).Linetype;
    settings.Linewidth = ((BalloonShape)shape).Linewidth;
    settings.Size = ((BalloonShape)shape).Size;
    settings.Slant = ((BalloonShape)shape).Slant;
    settings.TextColor = ((BalloonShape)shape).TextColor;
    settings.UseLeadColor = ((BalloonShape)shape).UseLeadColor;
    settings.UseLeadLinetype = ((BalloonShape)shape).UseLeadLinetype;
    settings.UseLeadLinewidth = ((BalloonShape)shape).UseLeadLinewidth;
    settings.UseTextColor = ((BalloonShape)shape).UseTextColor;
}
else if(shape is DimensionShape)    // 寸法
{
    var settings = (DimensionSettings)style.Settings;
    
    // 半径寸法の場合
    if(shape is RadiusDimensionShape)
    {
        settings.AddRPhi = ((RadiusDimensionShape)shape).AddRPhi;
        settings.ArrowPosition = ((RadiusDimensionShape)shape).ArrowPosition;
        settings.StartArrowSize = ((RadiusDimensionShape)shape).StartArrowSize;
        settings.StartArrowType = ((RadiusDimensionShape)shape).StartArrowType;
        settings.StartOutsideLength = ((RadiusDimensionShape)shape).StartOutsideLength;
        settings.LengthRound = ((RadiusDimensionShape)shape).LengthRound;
        settings.LengthScale = ((RadiusDimensionShape)shape).LengthScale;
        settings.LengthUnitFormatType = ((RadiusDimensionShape)shape).LengthUnitFormatType;
        settings.ShowStartDimensionLine = ((RadiusDimensionShape)shape).ShowStartDimensionLine;
        settings.SeparateText = ((RadiusDimensionShape)shape).SeparateText;
        settings.ShowFeetZero = ((RadiusDimensionShape)shape).ShowUnitZero1;
        settings.ShowInchZero = ((RadiusDimensionShape)shape).ShowUnitZero2;
        settings.ShowToleranceFeetZero = ((RadiusDimensionShape)shape).ShowToleranceUnitZero1;
        settings.ShowToleranceInchZero = ((RadiusDimensionShape)shape).ShowToleranceUnitZero2;
        settings.Tolerance1 = ((RadiusDimensionShape)shape).Tolerance1;
        settings.Tolerance2 = ((RadiusDimensionShape)shape).Tolerance2;
        settings.TolerancePrecision = ((RadiusDimensionShape)shape).TolerancePrecision;
        settings.LengthPrecision = ((RadiusDimensionShape)shape).Precision;
    }
    // 直径寸法の場合
    else if(shape is DiameterDimensionShape)
    {
        settings.AddRPhi = ((DiameterDimensionShape)shape).AddRPhi;
        settings.ArrowPosition = ((DiameterDimensionShape)shape).ArrowPosition;
        settings.StartArrowSize = ((DiameterDimensionShape)shape).StartArrowSize;
        settings.StartArrowType = ((DiameterDimensionShape)shape).StartArrowType;
        settings.StartOutsideLength = ((DiameterDimensionShape)shape).StartOutsideLength;
        settings.EndArrowSize = ((DiameterDimensionShape)shape).EndArrowSize;
        settings.EndArrowType = ((DiameterDimensionShape)shape).EndArrowType;
        settings.EndOutsideLength = ((DiameterDimensionShape)shape).EndOutsideLength;
        settings.LengthRound = ((DiameterDimensionShape)shape).LengthRound;
        settings.LengthScale = ((DiameterDimensionShape)shape).LengthScale;
        settings.LengthUnitFormatType = ((DiameterDimensionShape)shape).LengthUnitFormatType;
        settings.SeparateText = ((DiameterDimensionShape)shape).SeparateText;
        settings.ShowStartDimensionLine = ((DiameterDimensionShape)shape).ShowStartDimensionLine;
        settings.ShowEndDimensionLine = ((DiameterDimensionShape)shape).ShowEndDimensionLine;
        settings.ShowFeetZero = ((DiameterDimensionShape)shape).ShowUnitZero1;
        settings.ShowInchZero = ((DiameterDimensionShape)shape).ShowUnitZero2;
        settings.ShowToleranceFeetZero = ((DiameterDimensionShape)shape).ShowToleranceUnitZero1;
        settings.ShowToleranceInchZero = ((DiameterDimensionShape)shape).ShowToleranceUnitZero2;
        settings.Tolerance1 = ((DiameterDimensionShape)shape).Tolerance1;
        settings.Tolerance2 = ((DiameterDimensionShape)shape).Tolerance2;
        settings.TolerancePrecision = ((DiameterDimensionShape)shape).TolerancePrecision;
        settings.LengthPrecision = ((DiameterDimensionShape)shape).Precision;
    }
    // 角度寸法の場合
    else if(shape is AngularDimensionShape)
    {
        settings.AnglePrecision = ((AngularDimensionShape)shape).TolerancePrecision;
        settings.AngleUnitFormatType = ((AngularDimensionShape)shape).AngleUnitFormatType;
        settings.ArrowPosition = ((AngularDimensionShape)shape).ArrowPosition;
        settings.StartArrowSize = ((AngularDimensionShape)shape).StartArrowSize;
        settings.StartArrowType = ((AngularDimensionShape)shape).StartArrowType;
        settings.StartOutsideLength = ((AngularDimensionShape)shape).StartOutsideLength;
        settings.StartProjectionLineExtension = ((AngularDimensionShape)shape).StartProjectionLineExtension;
        settings.StartProjectionLineLength = ((AngularDimensionShape)shape).StartProjectionLineOffset;
        settings.EndArrowSize = ((AngularDimensionShape)shape).EndArrowSize;
        settings.EndArrowType = ((AngularDimensionShape)shape).EndArrowType;
        settings.EndOutsideLength = ((AngularDimensionShape)shape).EndOutsideLength;
        settings.EndProjectionLineExtension = ((AngularDimensionShape)shape).EndProjectionLineExtension;
        settings.EndProjectionLineLength = ((AngularDimensionShape)shape).EndProjectionLineOffset;
        settings.ProjectionLineColor = ((AngularDimensionShape)shape).ProjectionLineColor;
        settings.ProjectionLineLinetype = ((AngularDimensionShape)shape).ProjectionLineLinetype;
        settings.ProjectionLineLinewidth = ((AngularDimensionShape)shape).ProjectionLineLinewidth;
        settings.ProjectionLineMode = ((AngularDimensionShape)shape).ProjectionLineMode;
        settings.ShowDegreeMinuteZero = ((AngularDimensionShape)shape).ShowUnitZero1;
        settings.ShowMinuteSecondZero = ((DimensionShape)shape).ShowUnitZero2;
        settings.ShowStartProjectionLine = ((AngularDimensionShape)shape).ShowStartProjectionLine;
        settings.ShowEndProjectionLine = ((AngularDimensionShape)shape).ShowEndProjectionLine;
        settings.ShowStartDimensionLine = ((AngularDimensionShape)shape).ShowStartDimensionLine;
        settings.ShowEndDimensionLine = ((AngularDimensionShape)shape).ShowEndDimensionLine;
        settings.ShowToleranceDegreeMinuteZero = ((AngularDimensionShape)shape).ShowToleranceUnitZero1;
        settings.ShowToleranceMinuteSecondZero = ((AngularDimensionShape)shape).ShowToleranceUnitZero2;
        settings.ShowToleranceFeetZero = ((AngularDimensionShape)shape).ShowToleranceUnitZero1;
        settings.ShowToleranceInchZero = ((AngularDimensionShape)shape).ShowToleranceUnitZero2;
        settings.ToleranceAngle1 = ((AngularDimensionShape)shape).Tolerance1;
        settings.ToleranceAngle2 = ((AngularDimensionShape)shape).Tolerance2;
        settings.ToleranceAnglePrecision = ((AngularDimensionShape)shape).Precision;
        settings.TolerancePrecision = ((AngularDimensionShape)shape).TolerancePrecision;
        settings.UseProjectionLineColor = ((AngularDimensionShape)shape).UseProjectionLineColor;
        settings.UseProjectionLineLinetype = ((AngularDimensionShape)shape).UseProjectionLineLinetype;
        settings.UseProjectionLineLinewidth = ((AngularDimensionShape)shape).UseProjectionLineLinewidth;

    }
    // 円弧寸法の場合
    else if(shape is ArcDimensionShape)
    {
        settings.ArcDimensionProjectionLineRadialMode = ((ArcDimensionShape)shape).ArcDimensionProjectionLineRadialMode;
        settings.ArcSymbolPositionType = ((ArcDimensionShape)shape).ArcSymbolPositionType;
        settings.ArrowPosition = ((ArcDimensionShape)shape).ArrowPosition;
        settings.StartArrowSize = ((ArcDimensionShape)shape).StartArrowSize;
        settings.StartArrowType = ((ArcDimensionShape)shape).StartArrowType;
        settings.StartOutsideLength = ((ArcDimensionShape)shape).StartOutsideLength;
        settings.StartProjectionLineExtension = ((ArcDimensionShape)shape).StartProjectionLineExtension;
        settings.StartProjectionLineLength = ((ArcDimensionShape)shape).StartProjectionLineOffset;
        settings.EndArrowSize = ((ArcDimensionShape)shape).EndArrowSize;
        settings.EndArrowType = ((ArcDimensionShape)shape).EndArrowType;
        settings.EndOutsideLength = ((ArcDimensionShape)shape).EndOutsideLength;
        settings.EndProjectionLineExtension = ((ArcDimensionShape)shape).EndProjectionLineExtension;
        settings.EndProjectionLineLength = ((ArcDimensionShape)shape).EndProjectionLineOffset;
        settings.LengthRound = ((ArcDimensionShape)shape).LengthRound;
        settings.LengthScale = ((ArcDimensionShape)shape).LengthScale;
        settings.LengthUnitFormatType = ((ArcDimensionShape)shape).LengthUnitFormatType;
        settings.ProjectionLineColor = ((ArcDimensionShape)shape).ProjectionLineColor;
        settings.ProjectionLineLinetype = ((ArcDimensionShape)shape).ProjectionLineLinetype;
        settings.ProjectionLineLinewidth = ((ArcDimensionShape)shape).ProjectionLineLinewidth;
        settings.ProjectionLineMode = ((ArcDimensionShape)shape).ProjectionLineMode;
        settings.SeparateText = ((ArcDimensionShape)shape).SeparateText;
        settings.ShowStartProjectionLine = ((ArcDimensionShape)shape).ShowStartProjectionLine;
        settings.ShowEndProjectionLine = ((ArcDimensionShape)shape).ShowEndProjectionLine;
        settings.ShowStartDimensionLine = ((ArcDimensionShape)shape).ShowStartDimensionLine;
        settings.ShowEndDimensionLine = ((ArcDimensionShape)shape).ShowEndDimensionLine;
        settings.ShowFeetZero = ((ArcDimensionShape)shape).ShowUnitZero1;
        settings.ShowInchZero = ((ArcDimensionShape)shape).ShowUnitZero2;
        settings.ShowToleranceFeetZero = ((ArcDimensionShape)shape).ShowToleranceUnitZero1;
        settings.ShowToleranceInchZero = ((ArcDimensionShape)shape).ShowToleranceUnitZero2;
        settings.Tolerance1 = ((ArcDimensionShape)shape).Tolerance1;
        settings.Tolerance2 = ((ArcDimensionShape)shape).Tolerance2;
        settings.TolerancePrecision = ((ArcDimensionShape)shape).TolerancePrecision;
        settings.UseProjectionLineColor = ((ArcDimensionShape)shape).UseProjectionLineColor;
        settings.UseProjectionLineLinetype = ((ArcDimensionShape)shape).UseProjectionLineLinetype;
        settings.UseProjectionLineLinewidth = ((ArcDimensionShape)shape).UseProjectionLineLinewidth;
        settings.LengthPrecision = ((ArcDimensionShape)shape).Precision;
    }
    // 長さ寸法の場合
    else if(shape is LinearDimensionShape)
    {
        settings.ArrowPosition = ((LinearDimensionShape)shape).ArrowPosition;
        settings.StartArrowSize = ((LinearDimensionShape)shape).StartArrowSize;
        settings.StartArrowType = ((LinearDimensionShape)shape).StartArrowType;
        settings.StartOutsideLength = ((LinearDimensionShape)shape).StartOutsideLength;
        settings.StartProjectionLineExtension = ((LinearDimensionShape)shape).StartProjectionLineExtension;
        settings.StartProjectionLineLength = ((LinearDimensionShape)shape).StartProjectionLineOffset;
        settings.EndArrowSize = ((LinearDimensionShape)shape).EndArrowSize;
        settings.EndArrowType = ((LinearDimensionShape)shape).EndArrowType;
        settings.EndOutsideLength = ((LinearDimensionShape)shape).EndOutsideLength;
        settings.EndProjectionLineExtension = ((LinearDimensionShape)shape).EndProjectionLineExtension;
        settings.EndProjectionLineLength = ((LinearDimensionShape)shape).EndProjectionLineOffset;
        settings.LengthRound = ((LinearDimensionShape)shape).LengthRound;
        settings.LengthScale = ((LinearDimensionShape)shape).LengthScale;
        settings.LengthUnitFormatType = ((LinearDimensionShape)shape).LengthUnitFormatType;
        settings.ProjectionLineColor = ((LinearDimensionShape)shape).ProjectionLineColor;
        settings.ProjectionLineLinetype = ((LinearDimensionShape)shape).ProjectionLineLinetype;
        settings.ProjectionLineLinewidth = ((LinearDimensionShape)shape).ProjectionLineLinewidth;
        settings.ProjectionLineMode = ((LinearDimensionShape)shape).ProjectionLineMode;
        settings.SeparateText = ((LinearDimensionShape)shape).SeparateText;
        settings.ShowStartProjectionLine = ((LinearDimensionShape)shape).ShowStartProjectionLine;
        settings.ShowEndProjectionLine = ((LinearDimensionShape)shape).ShowEndProjectionLine;
        settings.ShowStartDimensionLine = ((LinearDimensionShape)shape).ShowStartDimensionLine;
        settings.ShowEndDimensionLine = ((LinearDimensionShape)shape).ShowEndDimensionLine;
        settings.ShowFeetZero = ((LinearDimensionShape)shape).ShowUnitZero1;
        settings.ShowInchZero = ((LinearDimensionShape)shape).ShowUnitZero2;
        settings.ShowToleranceFeetZero = ((LinearDimensionShape)shape).ShowToleranceUnitZero1;
        settings.ShowToleranceInchZero = ((LinearDimensionShape)shape).ShowToleranceUnitZero2;
        settings.Tolerance1 = ((LinearDimensionShape)shape).Tolerance1;
        settings.Tolerance2 = ((LinearDimensionShape)shape).Tolerance2;
        settings.TolerancePrecision = ((LinearDimensionShape)shape).TolerancePrecision;
        settings.UseProjectionLineColor = ((LinearDimensionShape)shape).UseProjectionLineColor;
        settings.UseProjectionLineLinetype = ((LinearDimensionShape)shape).UseProjectionLineLinetype;
        settings.UseProjectionLineLinewidth = ((LinearDimensionShape)shape).UseProjectionLineLinewidth;
        settings.LengthPrecision = ((LinearDimensionShape)shape).Precision;
    }
    // 幾何公差の場合
    else if(shape is ToleranceShape)
    {
        settings.ShowFeetZero = ((ToleranceShape)shape).ShowUnitZero1;
        settings.ShowInchZero = ((ToleranceShape)shape).ShowUnitZero2;
        settings.ShowToleranceFeetZero = ((ToleranceShape)shape).ShowToleranceUnitZero1;
        settings.ShowToleranceInchZero = ((ToleranceShape)shape).ShowToleranceUnitZero2;
        settings.Tolerance1 = ((ToleranceShape)shape).Tolerance1;
        settings.Tolerance2 = ((ToleranceShape)shape).Tolerance2;
        settings.TolerancePrecision = ((ToleranceShape)shape).TolerancePrecision;
        settings.LengthPrecision = ((ToleranceShape)shape).Precision;
    }
    settings.AlwaysDimensionLineInside = ((DimensionShape)shape).AlwaysDimensionLineInside;
    settings.AutoArrowPosition = ((DimensionShape)shape).AutoArrowPosition;
    settings.Bold = ((DimensionShape)shape).Bold;
    settings.Color = ((DimensionShape)shape).Color;
    settings.DimensionTextAngle = ((DimensionShape)shape).DimensionTextAngle;
    settings.DimensionTextAngleType = ((DimensionShape)shape).DimensionTextAngleType;
    settings.DimensionTextDistance = ((DimensionShape)shape).DimensionTextDistance;
    settings.DimensionTextFullWidth = ((DimensionShape)shape).DimensionTextFullWidth;
    settings.DimensionTextHorizontalPosition = ((DimensionShape)shape).DimensionTextHorizontalPosition;
    settings.DimensionTextVerticalPosition = ((DimensionShape)shape).DimensionTextVerticalPosition;
    settings.ExtendDimensionLine = ((DimensionShape)shape).ExtendDimensionLine;
    settings.FontHeight = ((DimensionShape)shape).FontHeight;
    settings.FontName = ((DimensionShape)shape).FontName;
    settings.InsideTex2 = ((DimensionShape)shape).InsideTex2;
    settings.InsideText1 = ((DimensionShape)shape).InsideText1;
    settings.InsideTextHorizontalArrangeType = ((DimensionShape)shape).InsideTextHorizontalArrangeType;
    settings.InsideTextSizeRatio = ((DimensionShape)shape).InsideTextSizeRatio;
    settings.InsideTextType = ((DimensionShape)shape).InsideTextType;
    settings.InsideTextVerticalArrangeType = ((DimensionShape)shape).InsideTextVerticalArrangeType;
    settings.Linetype = ((DimensionShape)shape).Linetype;
    settings.Linewidth = ((DimensionShape)shape).Linewidth;
    settings.NotSettledArrowPositionMode = ((DimensionShape)shape).NotSettledArrowPositionMode;
    settings.PostText1 = ((DimensionShape)shape).PostText1;
    settings.PostText2 = ((DimensionShape)shape).PostText2;
    settings.PostTextHorizontalArrangeType = ((DimensionShape)shape).PostTextHorizontalArrangeType;
    settings.PostTextSizeRatio = ((DimensionShape)shape).PostTextSizeRatio;
    settings.PostTextType = ((DimensionShape)shape).PostTextType;
    settings.PostTextVerticalArrangeType = ((DimensionShape)shape).PostTextVerticalArrangeType;
    settings.PreText = ((DimensionShape)shape).PreText;
    settings.ShowAboveZero = ((DimensionShape)shape).ShowAboveZero;
    settings.ShowDimensionTextToleranceLimits = ((DimensionShape)shape).ShowDimensionTextToleranceLimits;
    settings.ShowToleranceAboveZero = ((DimensionShape)shape).ShowToleranceAboveZero;
    settings.ShowToleranceMinusZeroMark = ((DimensionShape)shape).ShowToleranceMinusZeroMark;
    settings.ShowToleranceZero = ((DimensionShape)shape).ShowToleranceZero;
    settings.ShowZero = ((DimensionShape)shape).ShowZero;
    settings.Slant = ((DimensionShape)shape).Slant;
    settings.Spacing = ((DimensionShape)shape).Spacing;
    settings.TextColor = ((DimensionShape)shape).TextColor;
    settings.ToleranceAddParenthesis = ((DimensionShape)shape).ToleranceAddParenthesis;
    settings.ToleranceHorizontalArrangeType = ((DimensionShape)shape).ToleranceHorizontalArrangeType;
    settings.ToleranceTextSizeRatio = ((DimensionShape)shape).ToleranceTextSizeRatio;
    settings.ToleranceType = ((DimensionShape)shape).ToleranceType;
    settings.ToleranceVerticalArrangeType = ((DimensionShape)shape).ToleranceVerticalArrangeType;
    settings.UseTextColor = ((DimensionShape)shape).UseTextColor;
    settings.WidthScale = ((DimensionShape)shape).WidthScale;
}
else if(shape is HatchShape)        // ハッチング
{
    var settings = (HatchSettings)style.Settings;

    settings.HatchType = ((HatchShape)shape).HatchType;
    if(((HatchShape)shape).HatchType == HatchType.Solid || ((HatchShape)shape).HatchType == HatchType.Pattern)
    {
        settings.Transparency = ((HatchShape)shape).Transparency;
        settings.BackgroundColor = ((HatchShape)shape).BackgroundColor;
    }   
    if(((HatchShape)shape).HatchType == HatchType.Pattern)
    {
        settings.ForegroundColor = ((HatchShape)shape).ForegroundColor;
        settings.PatternType = ((HatchShape)shape).PatternType;
    }
    if(((HatchShape)shape).HatchType == HatchType.Solid)
    {
        settings.ReverseColor = ((HatchShape)shape).ReverseColor;
    }
    if(((HatchShape)shape).HatchType == HatchType.Custom)
    {
        settings.CustomHatch = ((HatchShape)shape).CustomHatch;
    }

    settings.RegionColor = ((HatchShape)shape).RegionColor;
    settings.RegionLinetype = ((HatchShape)shape).RegionLinetype;
    settings.RegionLinewidth = ((HatchShape)shape).RegionLinewidth;
    settings.ShowRegion = ((HatchShape)shape).ShowRegion;
}
else
{
    return;
}

MessageBox.Show(styleName + "を登録しました");
